@@ -192,8 +192,8 @@ class ImportTree:
             definitions_to_imports=self.definitions_to_imports
         )
 
-    def cohesion(self):
-        df = self.get_packages_df()
+    def cohesion(self, resolver_func=get_absolute_path_to_package_and_version_dict):
+        df = self.get_packages_df(resolver_func)
         return Cohesion(score=df.drop_duplicates(subset='definition')['cohesion_score'].mean(),
                         definitions=df)
 
@@ -206,9 +206,9 @@ class ImportTree:
         df = def_with_imports.merge(self.import_data, left_on='import_code_str', right_on='code_str', how='left')
         return df
 
-    def get_packages_df(self):
+    def get_packages_df(self, resolver_func=get_absolute_path_to_package_and_version_dict):
         full = self.get_full_df()
-        dct, package_weight = get_absolute_path_to_package_and_version_dict()
+        dct, package_weight = resolver_func()
         full['dependency'] = full['path'].map(partial(get_dependency,
                                                       absolute_path_to_package_and_version_dict=dct))
         res = pd.DataFrame({
